@@ -71,13 +71,21 @@ def cleanup_value(value: any) -> any:
 def datetime_to_string(val: datetime.datetime) -> str:
     """Convert a datetime object to string.
 
+    If the supplied datetime does not specify a timezone,
+    it is assumed to be UTC.
+
     Args:
         val: The datetime object.
 
     Returns:
         datetime serialized to iso8601 format.
     """
-    return val.isoformat().replace('+00:00', 'Z')
+    if isinstance(val, datetime.datetime):
+        if val.tzinfo is None:
+            return val.isoformat() + 'Z'
+        val = val.astimezone(datetime.timezone.utc)
+        return val.isoformat().replace('+00:00', 'Z')
+    return val
 
 def string_to_datetime(string: str) -> datetime.datetime:
     """De-serializes string to datetime.
@@ -88,7 +96,34 @@ def string_to_datetime(string: str) -> datetime.datetime:
     Returns:
         the de-serialized string as a datetime object.
     """
-    return date_parser.parse(string)
+    val = date_parser.parse(string)
+    if val.tzinfo is not None:
+        return val
+    return val.replace(tzinfo=datetime.timezone.utc)
+
+def date_to_string(val: datetime.date) -> str:
+    """Convert a date object to string.
+
+    Args:
+        val: The date object.
+
+    Returns:
+        date serialized to `YYYY-MM-DD` format.
+    """
+    if isinstance(val, datetime.date):
+        return str(val)
+    return val
+
+def string_to_date(string: str) -> datetime.date:
+    """De-serializes string to date.
+
+    Args:
+        string: string containing date in 'YYYY-MM-DD' format.
+
+    Returns:
+        the de-serialized string as a date object.
+    """
+    return date_parser.parse(string).date()
 
 def convert_model(val: any) -> dict:
     """Convert a model object into an equivalent dict.
@@ -162,7 +197,7 @@ def __read_from_env_variables(service_name: str) -> dict:
         _parse_key_and_update_config(config, service_name, key, value)
     return config
 
-def __read_from_credential_file(service_name: str, separator: str = '=') -> dict:
+def __read_from_credential_file(service_name: str, *, separator: str = '=') -> dict:
     """Return a config object based on credentials file for a service.
 
     Args:
@@ -203,7 +238,7 @@ def __read_from_credential_file(service_name: str, separator: str = '=') -> dict
                     _parse_key_and_update_config(config, service_name, key, value)
     return config
 
-def _parse_key_and_update_config(config, service_name, key, value):
+def _parse_key_and_update_config(config: dict, service_name: str, key: str, value: str) -> None:
     service_name = service_name.replace(' ', '_').replace('-', '_').upper()
     if key.startswith(service_name):
         config[key[len(service_name) + 1:]] = value
